package com.ruoyi.invest.service;

import java.util.List;
import com.ruoyi.invest.domain.PosMachine;
import com.ruoyi.invest.domain.dto.PosMachineDto;
import com.ruoyi.invest.domain.vo.PosMachineVo;

/**
 * pos机信息Service接口
 *
 * @author tianyongbao
 * @date 2024-03-18
 */
public interface IPosMachineService
{
    /**
     * 查询pos机信息
     *
     * @param id pos机信息主键
     * @return pos机信息
     */
    public PosMachineVo selectPosMachineById(Long id);

    /**
     * 查询pos机信息列表
     *
     * @param posMachineDto pos机信息
     * @return pos机信息集合
     */
    public List<PosMachineVo> selectPosMachineList(PosMachineDto posMachineDto);

    /**
     * 新增pos机信息
     *
     * @param posMachine pos机信息
     * @return 结果
     */
    public int insertPosMachine(PosMachine posMachine);

    /**
     * 修改pos机信息
     *
     * @param posMachine pos机信息
     * @return 结果
     */
    public int updatePosMachine(PosMachine posMachine);

    /**
     * 批量删除pos机信息
     *
     * @param ids 需要删除的pos机信息主键集合
     * @return 结果
     */
    public int deletePosMachineByIds(Long[] ids);

    /**
     * 删除pos机信息信息
     *
     * @param id pos机信息主键
     * @return 结果
     */
    public int deletePosMachineById(Long id);
}
