package com.ruoyi.invest.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.invest.domain.PosMachine;
import com.ruoyi.invest.domain.vo.PosMachineVo;
import com.ruoyi.invest.domain.dto.PosMachineDto;
import com.ruoyi.invest.service.IPosMachineService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * pos机信息Controller
 *
 * @author tianyongbao
 * @date 2024-03-18
 */
@Api(tags=" pos机信息")
@RestController
@RequestMapping("/posmachine")
public class PosMachineController extends BaseController
{
    @Resource
    private IPosMachineService posMachineService;

    /**
     * 查询pos机信息列表
     */
    @ApiOperation(value="查询pos机信息列表",response = PosMachineVo.class)
    @RequiresPermissions("invest:posmachine:list")
    @GetMapping("/list")
    public TableDataInfo list(PosMachineDto posMachineDto)
    {
        startPage();
        List<PosMachineVo> list = posMachineService.selectPosMachineList(posMachineDto);
        return getDataTable(list);
    }

    /**
     * 导出pos机信息列表
     */
    @ApiOperation(value="导出pos机信息列表")
    @RequiresPermissions("invest:posmachine:export")
    @Log(title = "pos机信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PosMachineDto posMachineDto)
    {
        List<PosMachineVo> list = posMachineService.selectPosMachineList(posMachineDto);
        ExcelUtil<PosMachineVo> util = new ExcelUtil<PosMachineVo>(PosMachineVo.class);
        util.exportExcel(response, list, "pos机信息数据");
    }

    /**
     * 获取pos机信息详细信息
     */
    @ApiOperation(value="获取pos机信息详细信息")
    @RequiresPermissions("invest:posmachine:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(posMachineService.selectPosMachineById(id));
    }

    /**
     * 新增pos机信息
     */
    @ApiOperation(value="新增pos机信息")
    @RequiresPermissions("invest:posmachine:add")
    @Log(title = "pos机信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PosMachine posMachine)
    {
        return toAjax(posMachineService.insertPosMachine(posMachine));
    }

    /**
     * 修改pos机信息
     */
    @ApiOperation(value="修改pos机信息")
    @RequiresPermissions("invest:posmachine:edit")
    @Log(title = "pos机信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PosMachine posMachine)
    {
        return toAjax(posMachineService.updatePosMachine(posMachine));
    }

    /**
     * 删除pos机信息
     */
    @ApiOperation(value="删除pos机信息")
    @RequiresPermissions("invest:posmachine:remove")
    @Log(title = "pos机信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(posMachineService.deletePosMachineByIds(ids));
    }
}
